==> yaqcaffy_1.12.0.zip: yaqcaffy/doc/yaqcaffy.R <==
###################################################
### chunk number 1: data
###################################################
#line 91 "yaqcaffy.Rnw"
library("yaqcaffy")
library("affydata")
data(Dilution)
## probe intensities modification
tmp <- exprs(Dilution)
tmp[,1] <- tmp[,1]*2
exprs(Dilution) <- tmp


###################################################
### chunk number 2: yaqc
###################################################
#line 113 "yaqcaffy.Rnw"
yqc <-yaqc(Dilution,verbose=TRUE)
show(yqc)


###################################################
### chunk number 3: objectversion
###################################################
#line 120 "yaqcaffy.Rnw"
objectVersion(yqc)


###################################################
### chunk number 4: plotqual
###################################################
#line 140 "yaqcaffy.Rnw"
plot(yqc)


###################################################
### chunk number 5: outlier
###################################################
#line 151 "yaqcaffy.Rnw"
getOutliers(yqc,"sfs")


###################################################
### chunk number 6: merge
###################################################
#line 161 "yaqcaffy.Rnw"
yqc2<-yaqc(Dilution[,2:3])
arrays(yqc) 
arrays(yqc2)
yqc3<-merge(yqc,yqc2)
arrays(yqc3)


###################################################
### chunk number 7: myyaqccontolprobes eval=FALSE
###################################################
## #line 200 "yaqcaffy.Rnw"
## yqc <- yaqc(myAffyData,myYaqcControlProbes="yaqcControlProbes")


###################################################
### chunk number 8: maqcsubsetafx
###################################################
#line 208 "yaqcaffy.Rnw"
library(MAQCsubsetAFX)
data(refB)
d <- refB[,1]
sampleNames(d)


###################################################
### chunk number 9: reprodplot eval=FALSE
###################################################
## #line 219 "yaqcaffy.Rnw"
##  reprodPlot(d,"refA",normalize="rma")


###################################################
### chunk number 10: reprodplorFig
###################################################
#line 226 "yaqcaffy.Rnw"
reprodPlot(d,"test",normalize="none")


###################################################
### chunk number 11: sessioninfo
###################################################
#line 237 "yaqcaffy.Rnw"
toLatex(sessionInfo())

==> yaqcaffy_1.24.0.zip: yaqcaffy/doc/yaqcaffy.R <==
### R code from vignette source 'yaqcaffy.Rnw'

###################################################
### code chunk number 1: data
###################################################
library("yaqcaffy")
library("affydata")
data(Dilution)
## probe intensities modification
tmp <- exprs(Dilution)
tmp[,1] <- tmp[,1]*2
exprs(Dilution) <- tmp


###################################################
### code chunk number 2: yaqc
###################################################
yqc <-yaqc(Dilution,verbose=TRUE)
show(yqc)


###################################################
### code chunk number 3: objectversion
###################################################
objectVersion(yqc)


###################################################
### code chunk number 4: plotqual
###################################################
plot(yqc)


###################################################
### code chunk number 5: outlier
###################################################
getOutliers(yqc,"sfs")


###################################################
### code chunk number 6: merge
###################################################
yqc2<-yaqc(Dilution[,2:3])
arrays(yqc) 
arrays(yqc2)
yqc3<-merge(yqc,yqc2)
arrays(yqc3)


###################################################
### code chunk number 7: myyaqccontolprobes (eval = FALSE)
###################################################
## yqc <- yaqc(myAffyData,myYaqcControlProbes="yaqcControlProbes")


###################################################
### code chunk number 8: maqcsubsetafx
###################################################
library(MAQCsubsetAFX)
data(refB)
d <- refB[,1]
sampleNames(d)


###################################################
### code chunk number 9: reprodplot (eval = FALSE)
###################################################
##  reprodPlot(d,"refA",normalize="rma")


###################################################
### code chunk number 10: reprodplorFig
###################################################
reprodPlot(d,"test",normalize="none")


###################################################
### code chunk number 11: sessioninfo
###################################################
toLatex(sessionInfo())
